.. image:: https://github.com/globus/globus-cli/workflows/build/badge.svg?event=push
    :alt: build status
    :target: https://github.com/globus/globus-cli/actions?query=workflow%3Abuild

.. image:: https://img.shields.io/pypi/v/globus-cli.svg
    :alt: Latest Released Version
    :target: https://pypi.org/project/globus-cli/

.. image:: https://img.shields.io/pypi/pyversions/globus-cli.svg
    :alt: Supported Python Versions
    :target: https://img.shields.io/pypi/pyversions/globus-cli.svg

.. image:: https://img.shields.io/badge/License-Apache%202.0-blue.svg
    :alt: License
    :target: https://opensource.org/licenses/Apache-2.0

.. image:: https://results.pre-commit.ci/badge/github/globus/globus-cli/main.svg
   :target: https://results.pre-commit.ci/latest/github/globus/globus-cli/main
   :alt: pre-commit.ci status

..
    This is the badge style used by the isort repo itself, so we'll use their
    preferred colors

.. image:: https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336
    :alt: Import Style
    :target: https://pycqa.github.io/isort/

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :alt: Code Style
    :target: https://github.com/psf/black


Globus CLI
==========

A Command Line Interface to `Globus <https://www.globus.org/>`_.

Source Code: https://github.com/globus/globus-cli

Installation, Running, Other Documentation: https://docs.globus.org/cli

Bugs and Feature Requests
-------------------------

Bugs reports and feature requests are open submission, and should be filed at
https://github.com/globusonline/globus-cli/issues
